==> vokoscreen-ng_3.0.7.orig.tar.gz: vokoscreenNG-3.0.7/src/language/de_AT.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de_AT" version="2.1">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Ein oder mehrere Geräte auswählen</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Auf Fenster umschalten</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Auf Vollbild umschalten</translation>
    </message>
</context>
<context>
    <name>QvkCountdown</name>
    <message>
        <source>Countdown</source>
        <translation>Countdown</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Ein oder mehrere Geräte auswählen</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Die Aufnahme wird nicht gestartet, nicht genügend freier Speicherplatz.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Das Limit für den freien Speicherplatz ist erreicht.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Grenze für freien Plattenplatz</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Die Aufnahme wurde gestoppt, nicht genügend freier Speicherplatz.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Fenster</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Kein Dateimanager gefunden</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Bitte installiere einen Dateimanager</translation>
    </message>
    <message>
        <source>Desktop session is a Wayland session</source>
        <translation>Desktopsitzung ist eine Waylandsitzung</translation>
    </message>
    <message>
        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
        <translation>Zur Zeit wird Wayland nicht unterstützt. Ein Screencast zeigt einen schwarzen Bildschirm. Bitte melden Sie sich ab und starten Sie eine X11 Desktop-Sitzung</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Quellcode</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Webseite</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Übersetzungen</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Spende</translation>
    </message>
    <message>
        <source>Wayland desktop session detected</source>
        <translation>Wayland Desktopsitzung erkannt</translation>
    </message>
</context>
<context>
    <name>QvkPlayer</name>
    <message>
        <source>Open File</source>
        <translation>Öffne Datei</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Bereich</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Verlassen</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Verlassen</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Horizontal spiegeln</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Vertikal spiegeln</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>invertiert</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>grau</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Schwarz-weiß</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Entferne Fensterrahmen</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320*240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Kameraeinstellungen</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Bereich</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Lupe</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Countdown</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Videogröße:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Freier Plattenplatz:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Aufnahmezeit</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Frames</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videocodec</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audiocodec</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Qualität</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Mauscursor nicht aufnehmen</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Stunde</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minute</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Starte den Timer</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Stoppe Aufnahme nach</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Stunden</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minuten</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekunden</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videopfad</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Grenze für freien Plattenplatz</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Im Systray anzeigen</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Sekunden vor der Aufnahme warten</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Nach Aktualisierungen suchen</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Verfügbar</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Nicht verfügbar</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Ordner</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>invertiert</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>grau</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Sende Report</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Letzte Aufnahme abspielen</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Ordner öffnen</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimiert beim Start der Aufzeichnung</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Startet minimiert</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Horizontal spiegeln</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Vertikal spiegeln</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Schwarz-weiß</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Entferne Fensterrahmen</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Spende</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Alle Einstellungen beim nächsten Start zurücksetzen</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright und Lizenz von Bildern</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Screencast</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Player</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Log</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright und Lizenz von Bildern</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Öffne Datei</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Vorheriges Bild</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Nächstes Bild</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Stummschaltung</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Menü verschieben</translation>
    </message>
</context>
</TS>

==> vokoscreen-ng_3.1.0.orig.tar.gz: vokoscreenNG-3.1.0/src/language/de_AT.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de_AT">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Ein oder mehrere Geräte auswählen</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Auf Fenster umschalten</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Auf Vollbild umschalten</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Ein oder mehrere Geräte auswählen</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Kein Dateimanager gefunden</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Bitte installiere einen Dateimanager</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Die Aufnahme wird nicht gestartet, nicht genügend freier Speicherplatz.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Das Limit für den freien Speicherplatz ist erreicht.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Grenze für freien Plattenplatz</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Die Aufnahme wurde gestoppt, nicht genügend freier Speicherplatz.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Fenster</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Kein Dateimanager gefunden</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Bitte installiere einen Dateimanager</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Quellcode</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Webseite</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Übersetzungen</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Spende</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Ein oder mehrere Geräte auswählen</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Bereich</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Verlassen</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Lupe</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Verlassen</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Horizontal spiegeln</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Vertikal spiegeln</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>invertiert</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>grau</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Schwarz-weiß</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Entferne Fensterrahmen</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320*240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Kameraeinstellungen</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Bereich</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Lupe</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Countdown</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Videogröße:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Freier Plattenplatz:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Aufnahmezeit</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Frames</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videocodec</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audiocodec</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Qualität</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Mauscursor nicht aufnehmen</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Stunde</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minute</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Starte den Timer</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Stoppe Aufnahme nach</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Stunden</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minuten</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekunden</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videopfad</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Grenze für freien Plattenplatz</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Im Systray anzeigen</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Sekunden vor der Aufnahme warten</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Nach Aktualisierungen suchen</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Verfügbar</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Nicht verfügbar</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Ordner</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>invertiert</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>grau</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Sende Report</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Letzte Aufnahme abspielen</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Ordner öffnen</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimiert beim Start der Aufzeichnung</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Startet minimiert</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Horizontal spiegeln</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Vertikal spiegeln</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Schwarz-weiß</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Entferne Fensterrahmen</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Spende</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Alle Einstellungen beim nächsten Start zurücksetzen</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright und Lizenz von Bildern</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Screencast</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Player</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Log</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright und Lizenz von Bildern</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Öffne Datei</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Vorheriges Bild</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Nächstes Bild</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Stummschaltung</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Menü verschieben</translation>
    </message>
</context>
</TS>
